## FIT REMOTE FUNCTION

### function name: remote

- excute_testcase: Send a resquest message to the FIT tool with a list of scenario numbers for fault injection as arguments. 
parameter: list
return: dict

- is_testcase_complete: Takes the fault injection result as an argument and determines whether the fault injection was successfully completed.
parameter: dict
return: bool
